<!-- Please do not edit this file. Edit the `blah` field in the `package.json` instead. If in doubt, open an issue. -->


















# edit-json-file

 [![Support me on Patreon][badge_patreon]][patreon] [![Buy me a book][badge_amazon]][amazon] [![PayPal][badge_paypal_donate]][paypal-donations] [![Ask me anything](https://img.shields.io/badge/ask%20me-anything-1abc9c.svg)](https://github.com/IonicaBizau/ama) [![Version](https://img.shields.io/npm/v/edit-json-file.svg)](https://www.npmjs.com/package/edit-json-file) [![Downloads](https://img.shields.io/npm/dt/edit-json-file.svg)](https://www.npmjs.com/package/edit-json-file) [![Get help on Codementor](https://cdn.codementor.io/badges/get_help_github.svg)](https://www.codementor.io/@johnnyb?utm_source=github&utm_medium=button&utm_term=johnnyb&utm_campaign=github)

<a href="https://www.buymeacoffee.com/H96WwChMy" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/yellow_img.png" alt="Buy Me A Coffee"></a>







> Edit a json file with ease.

















## :cloud: Installation

```sh
# Using npm
npm install --save edit-json-file

# Using yarn
yarn add edit-json-file
```













## :clipboard: Example



```js
const editJsonFile = require("edit-json-file");

// If the file doesn't exist, the content will be an empty object by default.
let file = editJsonFile(`${__dirname}/foo.json`);

// Set a couple of fields
file.set("planet", "Earth");
file.set("city\\.name", "anytown");
file.set("name.first", "Johnny");
file.set("name.last", "B.");
file.set("is_student", false);
//Create or append to an array
file.append("classes", "fysics");
//You can even append objects
file.append("classes", { class: "Computer Science", where: "KULeuven" });


// Output the content
console.log(file.get());
// { planet: 'Earth',
//   city.name: 'anytown',
//   name: { first: 'Johnny', last: 'B.' },
//   is_student: false,
//   classes: [
//     'fysics',
//     {
//       'class': 'Computer Science',
//       'where': 'KULeuven'
//     }
//   ]
// }

//if you want to remove the last element from an array use pop
file.pop("classes")

// Save the data to the disk
file.save();

// Reload it from the disk
file = editJsonFile(`${__dirname}/foo.json`, {
    autosave: true
});

// Get one field
console.log(file.get("name.first"));
// => Johnny

// This will save it to disk
file.set("a.new.field.as.object", {
    hello: "world"
});

// Output the whole thing
console.log(file.toObject());
// { planet: 'Earth',
//   name: { first: 'Johnny', last: 'B.' },
//   is_student: false,
//   a: { new: { field: [Object] } } }
```












## :question: Get Help

There are few ways to get help:



 1. Please [post questions on Stack Overflow](https://stackoverflow.com/questions/ask). You can open issues with questions, as long you add a link to your Stack Overflow question.
 2. For bug reports and feature requests, open issues. :bug:
 3. For direct and quick help, you can [use Codementor](https://www.codementor.io/johnnyb). :rocket:







## :memo: Documentation


### `JsonEditor(path, options)`

#### Params

- **String** `path`: The path to the JSON file.
- **Object** `options`: An object containing the following fields:
 - `stringify_width` (Number): The JSON stringify indent width (default: `2`).
 - `stringify_fn` (Function): A function used by `JSON.stringify`.
 - `stringify_eol` (Boolean): Wheter to add the new line at the end of the file or not (default: `false`)
 - `ignore_dots` (Boolean): Wheter to use the path including dots or have an object structure (default: `false`)
 - `autosave` (Boolean): Save the file when setting some data in it.

#### Return
- **JsonEditor** The `JsonEditor` instance.

### `set(path, value, options)`
Set a value in a specific path.

#### Params

- **String** `path`: The object path.
- **Anything** `value`: The value.
- **Object** `options`: The options for set-value (applied only when {ignore_dots} file option is false)

#### Return
- **JsonEditor** The `JsonEditor` instance.

### `get(path)`
Get a value in a specific path.

#### Params

- **String** `path`:

#### Return
- **Value** The object path value.

### `unset(path)`
Remove a path from a JSON object.

#### Params

- **String** `path`: The object path.

#### Return
- **JsonEditor** The `JsonEditor` instance.

### `append(path, value)`
Appends a value/object to a specific path.
If the path is empty it wil create a list.

#### Params

- **String** `path`: The object path.
- **Anything** `value`: The value.

#### Return
- **JsonEditor** The `JsonEditor` instance.

### `pop(path)`
Pop an array from a specific path.

#### Params

- **String** `path`: The object path.

#### Return
- **JsonEditor** The `JsonEditor` instance.

### `read(cb)`
Read the JSON file.

#### Params

- **Function** `cb`: An optional callback function which will turn the function into an asynchronous one.

#### Return
- **Object** The object parsed as object or an empty object by default.

### `read(The, cb)`
write
Write the JSON file.

#### Params

- **String** `The`: file content.
- **Function** `cb`: An optional callback function which will turn the function into an asynchronous one.

#### Return
- **JsonEditor** The `JsonEditor` instance.

### `empty(cb)`
Empty the JSON file content.

#### Params

- **Function** `cb`: The callback function.

### `toString()`
Get the current data as string.

#### Return
- **string** The data as string.

### `save(cb)`
Save the file back to disk.

#### Params

- **Function** `cb`: An optional callback function which will turn the function into an asynchronous one.

#### Return
- **JsonEditor** The `JsonEditor` instance.

### `toObject()`

#### Return
- **Object** The data object.

### `editJsonFile(path, options)`
Edit a json file.

#### Params

- **String** `path`: The path to the JSON file.
- **Object** `options`: An object containing the following fields:

#### Return
- **JsonEditor** The `JsonEditor` instance.














## :yum: How to contribute
Have an idea? Found a bug? See [how to contribute][contributing].


## :sparkling_heart: Support my projects
I open-source almost everything I can, and I try to reply to everyone needing help using these projects. Obviously,
this takes time. You can integrate and use these projects in your applications *for free*! You can even change the source code and redistribute (even resell it).

However, if you get some profit from this or just want to encourage me to continue creating stuff, there are few ways you can do it:


 - Starring and sharing the projects you like :rocket:
 - [![Buy me a book][badge_amazon]][amazon]—I love books! I will remember you after years if you buy me one. :grin: :book:
 - [![PayPal][badge_paypal]][paypal-donations]—You can make one-time donations via PayPal. I'll probably buy a ~~coffee~~ tea. :tea:
 - [![Support me on Patreon][badge_patreon]][patreon]—Set up a recurring monthly donation and you will get interesting news about what I'm doing (things that I don't share with everyone).
 - **Bitcoin**—You can send me bitcoins at this address (or scanning the code below): `1P9BRsmazNQcuyTxEqveUsnf5CERdq35V6`

    ![](https://i.imgur.com/z6OQI95.png)


Thanks! :heart:
















## :dizzy: Where is this library used?
If you are using this library in one of your projects, add it in this list. :sparkles:

 - `@acanto/laravel-scripts`
 - `@acanto/october-scripts`
 - `@acanto/workflow`
 - `@airbnb/nimbus`
 - `@allmywallets/specification`
 - `@anyopsos/cli`
 - `@aquestsrl/create-app-cli`
 - `@bemedev/build-tests`
 - `@bemedev/npm-publish`
 - `@bemedev/publish-command`
 - `@benits/teste-ui`
 - `@bitcoin-computer/node`
 - `@bronzw/create-discord-js-bot`
 - `@cc-cherry/carry-cli`
 - `@chakra-ui/codemod`
 - `@colorfulcompany/create-cc-jlmf`
 - `@crestron/ch5-shell-utilities-cli`
 - `@deboxsoft/plop-generator`
 - `@dolittle/vanir-cli`
 - `@dolittle/vanir-common`
 - `@dolittle/vanir-features`
 - `@dolittle/webpack`
 - `@dricup/dricup-cli`
 - `@elastosfoundation/trinity-cli`
 - `@elementarui/elementar-cli`
 - `@empirica/meteor-deploy`
 - `@fanxie/cli`
 - `@farazahmad759/dricup-crud-express`
 - `@formbird/core`
 - `@frdl/legacy-and-deprecations-fallback`
 - `@geesmart/zx-utils`
 - `@geesmart/zxlib`
 - `@genesislcap/build-kit`
 - `@genesislcap/foundation-cli`
 - `@genesislcap/genx2`
 - `@grogqli/server`
 - `@hyron/cli`
 - `@imklau/react-app`
 - `@imklau/react-boilerplate`
 - `@j.u.p.iter/jupiter-scripts`
 - `@jianghe/sand-cli`
 - `@johnlindquist/next-lesson`
 - `@kcom/package-tools`
 - `@kylehue/create-app`
 - `@malmo/cli`
 - `@marvinkome/create-node-app`
 - `@mateusznejman/neutralinojs-neu-piskel`
 - `@mianfrigo/express-typescript-generator`
 - `@mtmeyer/create-react-figma-plugin`
 - `@nattyjs/cli`
 - `@neutralinojs/neu`
 - `@olmokit/cli`
 - `@orhanemree/create-template`
 - `@panfilo/express-template`
 - `@perlatsp/devild`
 - `@postlight/node-typescript-starter-kit`
 - `@rajzik/lumos`
 - `@s-ui/changelog`
 - `@sapling/cli`
 - `@sevta/cli`
 - `@shoveller/copy-package`
 - `@something.technology/core`
 - `@spazious/config`
 - `@spazious/eslint-config`
 - `@spazious/storybook-config`
 - `@spazious/ts-config`
 - `@superjs/require-auto`
 - `@teamhive/angular-npm-seed`
 - `@ten24group/cli24`
 - `@tinyhttp/cli`
 - `@triptyk/nfw-cli`
 - `@williarts/williarts-commons`
 - `@wonderland/cli-plugin-new`
 - `@wonderland/cli-plugin-serverless`
 - `@wonderland/new`
 - `@xploration-tech/xtouch`
 - `admooh-cli`
 - `appium-reporter-plugin`
 - `axereos-hopes`
 - `baelte-cli`
 - `base-express-app-starter`
 - `bhc-cli`
 - `blazar-cli`
 - `blip-lang`
 - `bloggify-tools`
 - `boilerplate-templify-cli`
 - `bp-create-block`
 - `bt-translate`
 - `bucket-cli`
 - `build-swan-plugin`
 - `cap-utils`
 - `chakra-12345`
 - `changelog-make`
 - `check-dependency-version-consistency`
 - `chrome-extension-maker`
 - `cli-json-edit`
 - `cmd-assistant`
 - `consequunturquae`
 - `copancs-microservice-teemplate`
 - `copancs-microservice-template`
 - `create-any-app`
 - `create-express-template`
 - `create-express-ts-api`
 - `create-express-typescript-application`
 - `create-fw`
 - `create-itk-app`
 - `create-next-library`
 - `create-nextjs-skeleton`
 - `create-nuxt-typescript-component`
 - `create-ts-jest`
 - `create-wapi-app`
 - `create-web-app-template`
 - `crestron-angular-theme`
 - `cucu-generator`
 - `cz-ekthos`
 - `d-bot-script`
 - `def-struct`
 - `deploi`
 - `deployqb`
 - `dex-cli`
 - `deyarn`
 - `doggoreportbot`
 - `dricup`
 - `dricup-cli`
 - `dukecbe`
 - `easybackup`
 - `ecochat-term`
 - `env-to-now-json`
 - `evophp`
 - `express-generator-typescript`
 - `express-generator-typescript-k8s`
 - `express-ts-app`
 - `extracct`
 - `feeder-cli`
 - `fix-package-versions`
 - `fixed-minor-patch-package-json`
 - `fluxxo-generator`
 - `forcemanager-cli`
 - `git-normalize`
 - `gitversion-tool`
 - `grafpad`
 - `grelease`
 - `guser`
 - `gyaon-cli`
 - `h4cksterbot`
 - `iffe-cli`
 - `iffe-commit`
 - `infinicli`
 - `infinitumcli`
 - `intelliter`
 - `jad-node-ts-kit`
 - `jollof-cli`
 - `jollofjs`
 - `json-config-ts`
 - `kanuki-cli`
 - `kape`
 - `karmacv-themes`
 - `kikd`
 - `lazlodb`
 - `lerna-from-npm`
 - `live-stream-radio`
 - `lyo`
 - `malmo`
 - `menreiki-init`
 - `menreiki2`
 - `mf-webpack-plugin`
 - `mobcoder-node-express-typescript-generator`
 - `modern-node-starter`
 - `modern-project-generator`
 - `mongoose-auto-api.cli`
 - `monstro`
 - `moodui`
 - `mtm-cli`
 - `my-chakra-ui`
 - `nestgram`
 - `neu-forge`
 - `new-express-app`
 - `next-nodecms`
 - `next-templates`
 - `nipinit`
 - `node-mvc-cli`
 - `node-rg`
 - `nodman-cli`
 - `noir-wp-cli`
 - `ontrac`
 - `ootb-express-app`
 - `opticore-core-module`
 - `package-to-local`
 - `pandocuments`
 - `pipe-boy`
 - `pkgmngrgui`
 - `project-initializer`
 - `rcg-mc`
 - `react-easy-boilerplate`
 - `react-native-dom-expo`
 - `react-sgh-scaffolding`
 - `react-vscode-cli`
 - `returrn`
 - `robinhood-yolo`
 - `roboto-cli`
 - `semcom`
 - `sheetbase-cli`
 - `sicode-generate-starter`
 - `simple-etg`
 - `simple-rtg`
 - `simple-webpack-starter`
 - `sisback`
 - `soft-add-dependencies`
 - `srf-deploy-qb`
 - `ss-clean-slate`
 - `starfleet-cli`
 - `striplet`
 - `svag-cli-utils`
 - `temporenesciunt`
 - `term-of-the-day`
 - `torder-vue-cli`
 - `ts-express-starter`
 - `tsoak`
 - `typescript-express-starter`
 - `typescript-fastify-starter`
 - `typescript-koa-starter`
 - `typescript-nest-starter`
 - `typescript-react-native-starter`
 - `typescript-react-starter`
 - `typescript-vue-starter`
 - `uiseeds`
 - `uspk-ui`
 - `uteveniet`
 - `vcommit-cli`
 - `webify-generator`
 - `zoral-generator`











## :scroll: License

[MIT][license] © [Ionică Bizău][website]






[license]: /LICENSE
[website]: https://ionicabizau.net
[contributing]: /CONTRIBUTING.md
[docs]: /DOCUMENTATION.md
[badge_patreon]: https://ionicabizau.github.io/badges/patreon.svg
[badge_amazon]: https://ionicabizau.github.io/badges/amazon.svg
[badge_paypal]: https://ionicabizau.github.io/badges/paypal.svg
[badge_paypal_donate]: https://ionicabizau.github.io/badges/paypal_donate.svg
[patreon]: https://www.patreon.com/ionicabizau
[amazon]: http://amzn.eu/hRo9sIZ
[paypal-donations]: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=RVXDDLKKLQRJW
